@@ -5,23 +5,16 @@
 
 #include "spectrumparser.h"
 
-#include "spectrum.h"
 
-#include <QDebug>
-#include <QFile>
+#include "kalzium_libscience_debug.h"
 #include <QList>
 
 class SpectrumParser::Private
 {
 public:
     Private()
-            : currentSpectrum(nullptr),
-            inMetadata_(false),
-            inSpectrum_(false),
-            inSpectrumList_(false),
-            inPeakList_(false),
-            inPeak_(false)
-    {}
+    {
+    }
 
     ~Private()
     {
@@ -29,23 +22,24 @@ public:
         delete currentPeak;
     }
 
-    Spectrum * currentSpectrum;
-    Spectrum::peak * currentPeak;
+    Spectrum *currentSpectrum = nullptr;
+    Spectrum::peak *currentPeak = nullptr;
 
-    bool inMetadata_;
-    bool inSpectrum_;
-    bool inSpectrumList_;
-    bool inPeakList_;
-    bool inPeak_;
+    bool inMetadata_ = false;
+    bool inSpectrum_ = false;
+    bool inSpectrumList_ = false;
+    bool inPeakList_ = false;
+    bool inPeak_ = false;
 
     double wavelength;
     int intensity;
 
-    QList<Spectrum*> spectra;
+    QList<Spectrum *> spectra;
 };
 
 SpectrumParser::SpectrumParser()
-        : QXmlDefaultHandler(), d(new Private)
+    : QXmlDefaultHandler()
+    , d(new Private)
 {
 }
 
@@ -54,14 +48,13 @@ SpectrumParser::~SpectrumParser()
     delete d;
 }
 
-bool SpectrumParser::startElement(const QString&, const QString &localName, const QString&, const QXmlAttributes &attrs)
+bool SpectrumParser::startElement(const QString &, const QString &localName, const QString &, const QXmlAttributes &attrs)
 {
     if (localName == QLatin1String("spectrum")) {
-
         d->currentSpectrum = new Spectrum();
         d->inSpectrum_ = true;
 
-        //now save the element of the current spectrum
+        // now save the element of the current spectrum
         for (int i = 0; i < attrs.length(); ++i) {
             if (attrs.localName(i) == QLatin1String("id")) {
                 currentElementID = attrs.value(i);
@@ -84,10 +77,14 @@ bool SpectrumParser::startElement(const QString&, const QString &localName, cons
     return true;
 }
 
-bool SpectrumParser::endElement(const QString&, const QString& localName, const QString &)
+bool SpectrumParser::endElement(const QString &, const QString &localName, const QString &)
 {
     if (localName == QLatin1String("spectrum")) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         int num = currentElementID.midRef(1).toInt();
+#else
+        int num = QStringView(currentElementID).mid(1).toInt();
+#endif
         d->currentSpectrum->setParentElementNumber(num);
 
         d->spectra.append(d->currentSpectrum);
@@ -97,7 +94,7 @@ bool SpectrumParser::endElement(const QString&, const QString& localName, const
     } else if (localName == QLatin1String("peakList")) {
         d->inSpectrumList_ = false;
     } else if (localName == QLatin1String("peak")) {
-//X             qDebug() << "in 'peak'" << " with this data: " << d->currentPeak->intensity << " (intensity)" ;
+        // X             qCDebug(KALZIUM_LIBSCIENCE_LOG) << "in 'peak'" << " with this data: " << d->currentPeak->intensity << " (intensity)" ;
         d->currentSpectrum->addPeak(d->currentPeak);
         d->currentPeak = nullptr;
         d->inPeak_ = false;
@@ -111,7 +108,7 @@ bool SpectrumParser::characters(const QString &ch)
     return true;
 }
 
-QList<Spectrum*> SpectrumParser::getSpectrums()
+QList<Spectrum *> SpectrumParser::getSpectrums() const
 {
     return d->spectra;
 }
